@@ -12,7 +12,7 @@ test -f protobuf-compiler_*.deb || \
 
 echo "*** Installing dependencies (hardcoded list)"
 
-apt-get install -y openjdk-6-jdk python python-support pkg-config
+apt-get install -y openjdk-6-jdk python python-support pkg-config zlib1g-dev
 
 echo "*** Installing packages"
 
@@ -20,7 +20,7 @@ dpkg -i *.deb
 
 cd /usr/share/doc/protobuf-compiler/examples
 
-export CLASSPATH=/usr/share/java/protobuf.jar
+export CLASSPATH=/usr/share/java/protobuf-java.jar
 
 echo "*** Building example programs"
 
